==> hx_components_flutter-1.0.15.tar.gz: lib/src/widgets/hx_card_button.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/hx_utils.dart';

class HxCardButton extends StatelessWidget {
  final Color? backgroundColor;
  final Color? textColor;
  final IconData icon;
  final VoidCallback homeNavigation;
  final HxText? text;

  const HxCardButton({
    super.key,
    this.backgroundColor = Colors.white,
    this.textColor = Colors.black,
    required this.icon,
    required this.homeNavigation,
    this.text,
  });

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: SizedBox(
        height: MediaQuery.of(context).size.height * 0.18,
        child: Card(
          color: backgroundColor,
          shadowColor: kcGrey,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10),
            side: const BorderSide(color: kcLightGrey),
          ),
          elevation: 2,
          child: InkWell(
            onTap: homeNavigation,
            splashColor: kcPrimaryColor,
            borderRadius: BorderRadius.circular(10),
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10),
              ),
              padding: const EdgeInsets.fromLTRB(20, 20, 20, 11),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Icon(
                    icon,
                    size: 33,
                    color: kcPrimaryColor,
                  ),
                  Expanded(
                    child: Container(alignment: Alignment.bottomLeft, child: text),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> hx_components_flutter-1.0.16.tar.gz: lib/src/widgets/hx_card_button.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/hx_utils.dart';

class HxCardButton extends StatelessWidget {
  final Color? backgroundColor;
  final Color? textColor;
  final IconData icon;
  final VoidCallback homeNavigation;
  final HxText? text;

  const HxCardButton({
    super.key,
    this.backgroundColor = Colors.white,
    this.textColor = Colors.black,
    required this.icon,
    required this.homeNavigation,
    this.text,
  });

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: SizedBox(
        height: MediaQuery.of(context).size.height * 0.18,
        child: Card(
          color: backgroundColor,
          shadowColor: kcGrey,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10),
            side: const BorderSide(color: kcLightGrey),
          ),
          elevation: 2,
          child: InkWell(
            onTap: homeNavigation,
            splashColor: kcPrimaryColor,
            borderRadius: BorderRadius.circular(10),
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10),
              ),
              padding: const EdgeInsets.fromLTRB(20, 20, 20, 11),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Icon(
                    icon,
                    size: 33,
                    color: kcPrimaryColor,
                  ),
                  Container(alignment: Alignment.bottomLeft, child: text),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
